"""Auto-generated RESID data"""
# DO NOT EDIT - generated by gen_resid.py

import warnings

from .dclass import ResidInfo

VERSION = "1.032.4"

try:
    RESID_MODIFICATIONS: dict[str, ResidInfo] = {
        "AA0002": ResidInfo(
        id="AA0002",
        name="L-arginine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0005": ResidInfo(
        id="AA0005",
        name="L-cysteine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0007": ResidInfo(
        id="AA0007",
        name="L-glutamine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0008": ResidInfo(
        id="AA0008",
        name="glycine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0009": ResidInfo(
        id="AA0009",
        name="L-histidine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0010": ResidInfo(
        id="AA0010",
        name="L-isoleucine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0011": ResidInfo(
        id="AA0011",
        name="L-leucine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0012": ResidInfo(
        id="AA0012",
        name="L-lysine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0013": ResidInfo(
        id="AA0013",
        name="L-methionine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0014": ResidInfo(
        id="AA0014",
        name="L-phenylalanine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0015": ResidInfo(
        id="AA0015",
        name="L-proline residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0016": ResidInfo(
        id="AA0016",
        name="L-serine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0017": ResidInfo(
        id="AA0017",
        name="L-threonine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0018": ResidInfo(
        id="AA0018",
        name="L-tryptophan residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0019": ResidInfo(
        id="AA0019",
        name="L-tyrosine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0020": ResidInfo(
        id="AA0020",
        name="L-valine residue",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0026": ResidInfo(
        id="AA0026",
        name="(2S,3R)-3-hydroxyasparagine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0027": ResidInfo(
        id="AA0027",
        name="(2S,3R)-3-hydroxyaspartic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0029": ResidInfo(
        id="AA0029",
        name="3-hydroxy-L-proline",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0032": ResidInfo(
        id="AA0032",
        name="L-gamma-carboxyglutamic acid",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
        "AA0033": ResidInfo(
        id="AA0033",
        name="L-aspartic 4-phosphoric anhydride",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0034": ResidInfo(
        id="AA0034",
        name="S-phospho-L-cysteine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0035": ResidInfo(
        id="AA0035",
        name="1'-phospho-L-histidine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0036": ResidInfo(
        id="AA0036",
        name="3'-phospho-L-histidine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0037": ResidInfo(
        id="AA0037",
        name="O-phospho-L-serine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0038": ResidInfo(
        id="AA0038",
        name="O-phospho-L-threonine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0039": ResidInfo(
        id="AA0039",
        name="O4'-phospho-L-tyrosine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0040": ResidInfo(
        id="AA0040",
        name="2'-[3-carboxamido-3-(trimethylammonio)propyl]-L-histidine",
        formula="C7H15N2O",
        monoisotopic_mass=143.11789,
        average_mass=143.21,
        dict_composition={'C': 7, 'H': 15, 'N': 2, 'O': 1},
    ),
        "AA0041": ResidInfo(
        id="AA0041",
        name="N-acetyl-L-alanine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0042": ResidInfo(
        id="AA0042",
        name="N-acetyl-L-aspartic acid",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0044": ResidInfo(
        id="AA0044",
        name="N-acetyl-L-glutamic acid",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0045": ResidInfo(
        id="AA0045",
        name="N-acetyl-L-glutamine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0046": ResidInfo(
        id="AA0046",
        name="N-acetylglycine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0047": ResidInfo(
        id="AA0047",
        name="N-acetyl-L-isoleucine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0048": ResidInfo(
        id="AA0048",
        name="N2-acetyl-L-lysine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0049": ResidInfo(
        id="AA0049",
        name="N-acetyl-L-methionine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0050": ResidInfo(
        id="AA0050",
        name="N-acetyl-L-proline",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0052": ResidInfo(
        id="AA0052",
        name="N-acetyl-L-threonine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0053": ResidInfo(
        id="AA0053",
        name="N-acetyl-L-tyrosine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0054": ResidInfo(
        id="AA0054",
        name="N-acetyl-L-valine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0055": ResidInfo(
        id="AA0055",
        name="N6-acetyl-L-lysine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0056": ResidInfo(
        id="AA0056",
        name="S-acetyl-L-cysteine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0057": ResidInfo(
        id="AA0057",
        name="N-formylglycine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
        "AA0058": ResidInfo(
        id="AA0058",
        name="N-D-glucuronoylglycine",
        formula="C6H8O6",
        monoisotopic_mass=176.032088,
        average_mass=176.12,
        dict_composition={'C': 6, 'H': 8, 'O': 6},
    ),
        "AA0060": ResidInfo(
        id="AA0060",
        name="N-palmitoyl-L-cysteine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
        "AA0061": ResidInfo(
        id="AA0061",
        name="N-methyl-L-alanine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0062": ResidInfo(
        id="AA0062",
        name="N,N,N-trimethyl-L-alanine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
        "AA0063": ResidInfo(
        id="AA0063",
        name="N-methylglycine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0064": ResidInfo(
        id="AA0064",
        name="N-methyl-L-methionine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0065": ResidInfo(
        id="AA0065",
        name="N-methyl-L-phenylalanine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0066": ResidInfo(
        id="AA0066",
        name="N,N-dimethyl-L-proline",
        formula="C2H5",
        monoisotopic_mass=29.038577,
        average_mass=29.06,
        dict_composition={'C': 2, 'H': 5},
    ),
        "AA0067": ResidInfo(
        id="AA0067",
        name="symmetric dimethyl-L-arginine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0068": ResidInfo(
        id="AA0068",
        name="asymmetric dimethyl-L-arginine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0070": ResidInfo(
        id="AA0070",
        name="N4-methyl-L-asparagine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0071": ResidInfo(
        id="AA0071",
        name="N5-methyl-L-glutamine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0073": ResidInfo(
        id="AA0073",
        name="3'-methyl-L-histidine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0074": ResidInfo(
        id="AA0074",
        name="N6,N6,N6-trimethyl-L-lysine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
        "AA0075": ResidInfo(
        id="AA0075",
        name="N6,N6-dimethyl-L-lysine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0076": ResidInfo(
        id="AA0076",
        name="N6-methyl-L-lysine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0077": ResidInfo(
        id="AA0077",
        name="N6-palmitoyl-L-lysine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
        "AA0078": ResidInfo(
        id="AA0078",
        name="N6-myristoyl-L-lysine",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
        "AA0080": ResidInfo(
        id="AA0080",
        name="O-palmitoyl-L-serine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
        "AA0081": ResidInfo(
        id="AA0081",
        name="L-alanine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0082": ResidInfo(
        id="AA0082",
        name="L-arginine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0083": ResidInfo(
        id="AA0083",
        name="L-asparagine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0084": ResidInfo(
        id="AA0084",
        name="L-aspartic acid 1-amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0085": ResidInfo(
        id="AA0085",
        name="L-cysteine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0086": ResidInfo(
        id="AA0086",
        name="L-glutamine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0087": ResidInfo(
        id="AA0087",
        name="L-glutamic acid 1-amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0088": ResidInfo(
        id="AA0088",
        name="glycine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0089": ResidInfo(
        id="AA0089",
        name="L-histidine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0090": ResidInfo(
        id="AA0090",
        name="L-isoleucine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0091": ResidInfo(
        id="AA0091",
        name="L-leucine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0092": ResidInfo(
        id="AA0092",
        name="L-lysine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0093": ResidInfo(
        id="AA0093",
        name="L-methionine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0094": ResidInfo(
        id="AA0094",
        name="L-phenylalanine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0095": ResidInfo(
        id="AA0095",
        name="L-proline amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0096": ResidInfo(
        id="AA0096",
        name="L-serine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0098": ResidInfo(
        id="AA0098",
        name="L-tryptophan amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0099": ResidInfo(
        id="AA0099",
        name="L-tyrosine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0100": ResidInfo(
        id="AA0100",
        name="L-valine amide",
        formula="HNO-1",
        monoisotopic_mass=-0.984016,
        average_mass=-0.98,
        dict_composition={'H': 1, 'N': 1, 'O': -1},
    ),
        "AA0101": ResidInfo(
        id="AA0101",
        name="L-cysteine methyl disulfide",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.09,
        dict_composition={'C': 1, 'H': 2, 'S': 1},
    ),
        "AA0106": ResidInfo(
        id="AA0106",
        name="S-palmitoyl-L-cysteine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
        "AA0108": ResidInfo(
        id="AA0108",
        name="S-(L-isoglutamyl)-L-cysteine",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
        "AA0109": ResidInfo(
        id="AA0109",
        name="2'-(S-L-cysteinyl)-L-histidine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0111": ResidInfo(
        id="AA0111",
        name="meso-lanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0112": ResidInfo(
        id="AA0112",
        name="(2S,3S,2'R)-3-methyllanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0113": ResidInfo(
        id="AA0113",
        name="3'-(S-L-cysteinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0114": ResidInfo(
        id="AA0114",
        name="N6-carboxy-L-lysine",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
        "AA0115": ResidInfo(
        id="AA0115",
        name="N6-1-carboxyethyl-L-lysine",
        formula="C3H4O2",
        monoisotopic_mass=72.021129,
        average_mass=72.06,
        dict_composition={'C': 3, 'H': 4, 'O': 2},
    ),
        "AA0116": ResidInfo(
        id="AA0116",
        name="hypusine",
        formula="C4H9NO",
        monoisotopic_mass=87.068414,
        average_mass=87.12,
        dict_composition={'C': 4, 'H': 9, 'N': 1, 'O': 1},
    ),
        "AA0117": ResidInfo(
        id="AA0117",
        name="N6-biotinyl-L-lysine",
        formula="C10H14N2O2S",
        monoisotopic_mass=226.077599,
        average_mass=226.29,
        dict_composition={'C': 10, 'H': 14, 'N': 2, 'O': 2, 'S': 1},
    ),
        "AA0118": ResidInfo(
        id="AA0118",
        name="N6-lipoyl-L-lysine",
        formula="C8H12OS2",
        monoisotopic_mass=188.032957,
        average_mass=188.3,
        dict_composition={'C': 8, 'H': 12, 'O': 1, 'S': 2},
    ),
        "AA0119": ResidInfo(
        id="AA0119",
        name="N6-pyridoxal phosphate-L-lysine",
        formula="C8H8NO5P",
        monoisotopic_mass=229.014009,
        average_mass=229.13,
        dict_composition={'C': 8, 'H': 8, 'N': 1, 'O': 5, 'P': 1},
    ),
        "AA0120": ResidInfo(
        id="AA0120",
        name="N6-retinylidene-L-lysine",
        formula="C20H26",
        monoisotopic_mass=266.203451,
        average_mass=266.43,
        dict_composition={'C': 20, 'H': 26},
    ),
        "AA0121": ResidInfo(
        id="AA0121",
        name="L-allysine",
        formula="H-3N-1O",
        monoisotopic_mass=-1.031634,
        average_mass=-1.03,
        dict_composition={'H': -3, 'N': -1, 'O': 1},
    ),
        "AA0122": ResidInfo(
        id="AA0122",
        name="L-2-aminoadipic acid",
        formula="H-3N-1O2",
        monoisotopic_mass=14.96328,
        average_mass=14.97,
        dict_composition={'H': -3, 'N': -1, 'O': 2},
    ),
        "AA0128": ResidInfo(
        id="AA0128",
        name="L-3-phenyllactic acid",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
        "AA0129": ResidInfo(
        id="AA0129",
        name="2-oxobutanoic acid",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
        "AA0130": ResidInfo(
        id="AA0130",
        name="N2-succinyl-L-tryptophan",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.07,
        dict_composition={'C': 4, 'H': 4, 'O': 3},
    ),
        "AA0131": ResidInfo(
        id="AA0131",
        name="S-phycocyanobilin-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
        "AA0132": ResidInfo(
        id="AA0132",
        name="S-phycoerythrobilin-L-cysteine",
        formula="C33H40N4O6",
        monoisotopic_mass=588.294785,
        average_mass=588.7,
        dict_composition={'C': 33, 'H': 40, 'N': 4, 'O': 6},
    ),
        "AA0133": ResidInfo(
        id="AA0133",
        name="S-phytochromobilin-L-cysteine",
        formula="C33H36N4O6",
        monoisotopic_mass=584.263485,
        average_mass=584.67,
        dict_composition={'C': 33, 'H': 36, 'N': 4, 'O': 6},
    ),
        "AA0134": ResidInfo(
        id="AA0134",
        name="heme-bis-L-cysteine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
        "AA0135": ResidInfo(
        id="AA0135",
        name="heme-L-cysteine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
        "AA0136": ResidInfo(
        id="AA0136",
        name="tetrakis-L-cysteinyl iron",
        formula="FeH-4",
        monoisotopic_mass=51.904735,
        average_mass=51.81,
        dict_composition={'Fe': 1, 'H': -4},
    ),
        "AA0137": ResidInfo(
        id="AA0137",
        name="tetrakis-L-cysteinyl diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
        "AA0138": ResidInfo(
        id="AA0138",
        name="hexakis-L-cysteinyl triiron trisulfide",
        formula="Fe3H-6S3",
        monoisotopic_mass=257.675721,
        average_mass=257.67,
        dict_composition={'Fe': 3, 'H': -6, 'S': 3},
    ),
        "AA0139": ResidInfo(
        id="AA0139",
        name="tris-L-cysteinyl triiron tetrasulfide",
        formula="Fe3H-3S4",
        monoisotopic_mass=292.671267,
        average_mass=292.75,
        dict_composition={'Fe': 3, 'H': -3, 'S': 4},
    ),
        "AA0140": ResidInfo(
        id="AA0140",
        name="tetrakis-L-cysteinyl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0141": ResidInfo(
        id="AA0141",
        name="L-cysteinyl-L-histidino-homocitryl molybdenum heptairon nonasulfide",
        formula="C7Fe7H6MoNO7S9",
        monoisotopic_mass=993.213036,
        average_mass=991.53,
        dict_composition={'C': 7, 'Fe': 7, 'H': 6, 'Mo': 1, 'N': 1, 'O': 7, 'S': 9},
    ),
        "AA0142": ResidInfo(
        id="AA0142",
        name="L-cysteinyl molybdopterin",
        formula="C10H11MoN5O8PS2",
        monoisotopic_mass=521.884074,
        average_mass=520.27,
        dict_composition={'C': 10, 'H': 11, 'Mo': 1, 'N': 5, 'O': 8, 'P': 1, 'S': 2},
    ),
        "AA0143": ResidInfo(
        id="AA0143",
        name="S-(8alpha-FAD)-L-cysteine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
        "AA0144": ResidInfo(
        id="AA0144",
        name="3'-(8alpha-FAD)-L-histidine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
        "AA0145": ResidInfo(
        id="AA0145",
        name="O4'-(8alpha-FAD)-L-tyrosine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
        "AA0147": ResidInfo(
        id="AA0147",
        name="L-2',4',5'-topaquinone",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.98,
        dict_composition={'H': -2, 'O': 2},
    ),
        "AA0148": ResidInfo(
        id="AA0148",
        name="L-tryptophyl quinone",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.98,
        dict_composition={'H': -2, 'O': 2},
    ),
        "AA0149": ResidInfo(
        id="AA0149",
        name="4'-(L-tryptophan)-L-tryptophyl quinone",
        formula="H-4O2",
        monoisotopic_mass=27.958529,
        average_mass=27.97,
        dict_composition={'H': -4, 'O': 2},
    ),
        "AA0150": ResidInfo(
        id="AA0150",
        name="O-phosphopantetheine-L-serine",
        formula="C11H21N2O6PS",
        monoisotopic_mass=340.085794,
        average_mass=340.33,
        dict_composition={'C': 11, 'H': 21, 'N': 2, 'O': 6, 'P': 1, 'S': 1},
    ),
        "AA0152": ResidInfo(
        id="AA0152",
        name="S-glucosyl-L-cysteine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0153": ResidInfo(
        id="AA0153",
        name="O5-glucosylgalactosyl-L-hydroxylysine",
        formula="C12H20O11",
        monoisotopic_mass=340.100561,
        average_mass=340.28,
        dict_composition={'C': 12, 'H': 20, 'O': 11},
    ),
        "AA0154": ResidInfo(
        id="AA0154",
        name="O-(N-acetylamino)galactosyl-L-serine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0155": ResidInfo(
        id="AA0155",
        name="O-(N-acetylamino)galactosyl-L-threonine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0156": ResidInfo(
        id="AA0156",
        name="1'-mannosyl-L-tryptophan",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0157": ResidInfo(
        id="AA0157",
        name="O4'-glucosyl-L-tyrosine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0158": ResidInfo(
        id="AA0158",
        name="N-asparaginyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0159": ResidInfo(
        id="AA0159",
        name="N-aspartyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0160": ResidInfo(
        id="AA0160",
        name="N-cysteinyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0161": ResidInfo(
        id="AA0161",
        name="N-glycyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0162": ResidInfo(
        id="AA0162",
        name="N-seryl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0163": ResidInfo(
        id="AA0163",
        name="N-alanyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0164": ResidInfo(
        id="AA0164",
        name="N-threonyl-glycosylphosphatidylinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0165": ResidInfo(
        id="AA0165",
        name="N-glycyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0166": ResidInfo(
        id="AA0166",
        name="N-seryl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0167": ResidInfo(
        id="AA0167",
        name="O-(phosphoribosyl dephospho-coenzyme A)-L-serine",
        formula="C26H42N7O19P3S",
        monoisotopic_mass=881.146903,
        average_mass=881.63,
        dict_composition={'C': 26, 'H': 42, 'N': 7, 'O': 19, 'P': 3, 'S': 1},
    ),
        "AA0168": ResidInfo(
        id="AA0168",
        name="omega-N-(ADP-ribosyl)-L-arginine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
        "AA0169": ResidInfo(
        id="AA0169",
        name="S-(ADP-ribosyl)-L-cysteine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
        "AA0170": ResidInfo(
        id="AA0170",
        name="L-glutamyl 5-glycerylphosphorylethanolamine",
        formula="C5H12NO5P",
        monoisotopic_mass=197.045309,
        average_mass=197.13,
        dict_composition={'C': 5, 'H': 12, 'N': 1, 'O': 5, 'P': 1},
    ),
        "AA0171": ResidInfo(
        id="AA0171",
        name="S-sulfo-L-cysteine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
        "AA0172": ResidInfo(
        id="AA0172",
        name="O4'-sulfo-L-tyrosine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
        "AA0173": ResidInfo(
        id="AA0173",
        name="L-bromohistidine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
        "AA0174": ResidInfo(
        id="AA0174",
        name="L-2'-bromophenylalanine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
        "AA0175": ResidInfo(
        id="AA0175",
        name="L-3'-bromophenylalanine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
        "AA0176": ResidInfo(
        id="AA0176",
        name="L-4'-bromophenylalanine",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
        "AA0177": ResidInfo(
        id="AA0177",
        name="3,3',5-triiodo-L-thyronine",
        formula="C6HI3O",
        monoisotopic_mass=469.716158,
        average_mass=469.79,
        dict_composition={'C': 6, 'H': 1, 'I': 3, 'O': 1},
    ),
        "AA0178": ResidInfo(
        id="AA0178",
        name="L-thyroxine",
        formula="C6I4O",
        monoisotopic_mass=595.612805,
        average_mass=595.68,
        dict_composition={'C': 6, 'I': 4, 'O': 1},
    ),
        "AA0179": ResidInfo(
        id="AA0179",
        name="6'-bromo-L-tryptophan",
        formula="BrH-1",
        monoisotopic_mass=77.910512,
        average_mass=78.9,
        dict_composition={'Br': 1, 'H': -1},
    ),
        "AA0183": ResidInfo(
        id="AA0183",
        name="(Z)-2,3-didehydrotyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0184": ResidInfo(
        id="AA0184",
        name="L-serine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0186": ResidInfo(
        id="AA0186",
        name="lactic acid",
        formula="H-1N-1",
        monoisotopic_mass=-15.010899,
        average_mass=-15.02,
        dict_composition={'H': -1, 'N': -1},
    ),
        "AA0187": ResidInfo(
        id="AA0187",
        name="L-alanine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0188": ResidInfo(
        id="AA0188",
        name="L-cysteine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0189": ResidInfo(
        id="AA0189",
        name="2-imino-glutamine 5-imidazolinone glycine",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0192": ResidInfo(
        id="AA0192",
        name="D-allo-isoleucine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0193": ResidInfo(
        id="AA0193",
        name="D-methionine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0194": ResidInfo(
        id="AA0194",
        name="D-phenylalanine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0196": ResidInfo(
        id="AA0196",
        name="D-asparagine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0197": ResidInfo(
        id="AA0197",
        name="D-leucine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0198": ResidInfo(
        id="AA0198",
        name="D-tryptophan",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0203": ResidInfo(
        id="AA0203",
        name="O4'-(phospho-5'-adenosine)-L-tyrosine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
        "AA0205": ResidInfo(
        id="AA0205",
        name="L-cysteine sulfenic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0207": ResidInfo(
        id="AA0207",
        name="S-4-hydroxycinnamyl-L-cysteine",
        formula="C9H6O2",
        monoisotopic_mass=146.036779,
        average_mass=146.14,
        dict_composition={'C': 9, 'H': 6, 'O': 2},
    ),
        "AA0211": ResidInfo(
        id="AA0211",
        name="N6-formyl-L-lysine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
        "AA0212": ResidInfo(
        id="AA0212",
        name="O4-arabinosyl-L-hydroxyproline",
        formula="C5H8O5",
        monoisotopic_mass=148.037173,
        average_mass=148.11,
        dict_composition={'C': 5, 'H': 8, 'O': 5},
    ),
        "AA0214": ResidInfo(
        id="AA0214",
        name="L-citrulline",
        formula="H-1N-1O",
        monoisotopic_mass=0.984016,
        average_mass=0.98,
        dict_composition={'H': -1, 'N': -1, 'O': 1},
    ),
        "AA0215": ResidInfo(
        id="AA0215",
        name="4-hydroxy-L-arginine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0216": ResidInfo(
        id="AA0216",
        name="N-(L-isoaspartyl)-L-cysteine",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
        "AA0217": ResidInfo(
        id="AA0217",
        name="2'-alpha-mannosyl-L-tryptophan",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0220": ResidInfo(
        id="AA0220",
        name="S-(6-FMN)-L-cysteine",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
        "AA0221": ResidInfo(
        id="AA0221",
        name="1'-(8alpha-FAD)-L-histidine",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
        "AA0222": ResidInfo(
        id="AA0222",
        name="omega-N-phospho-L-arginine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0224": ResidInfo(
        id="AA0224",
        name="alpha-1-microglobulin-Ig alpha complex chromophore",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0225": ResidInfo(
        id="AA0225",
        name="bis-L-cysteinyl bis-L-histidino diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
        "AA0226": ResidInfo(
        id="AA0226",
        name="hexakis-L-cysteinyl hexairon hexasulfide",
        formula="Fe6H-6S6",
        monoisotopic_mass=521.395649,
        average_mass=521.38,
        dict_composition={'Fe': 6, 'H': -6, 'S': 6},
    ),
        "AA0227": ResidInfo(
        id="AA0227",
        name="N6-(phospho-5'-adenosine)-L-lysine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
        "AA0228": ResidInfo(
        id="AA0228",
        name="N6-(phospho-5'-guanosine)-L-lysine",
        formula="C10H12N5O7P",
        monoisotopic_mass=345.047434,
        average_mass=345.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 7, 'P': 1},
    ),
        "AA0229": ResidInfo(
        id="AA0229",
        name="L-cysteine glutathione disulfide",
        formula="C10H15N3O6S",
        monoisotopic_mass=305.068156,
        average_mass=305.3,
        dict_composition={'C': 10, 'H': 15, 'N': 3, 'O': 6, 'S': 1},
    ),
        "AA0230": ResidInfo(
        id="AA0230",
        name="S-nitrosyl-L-cysteine",
        formula="H-1NO",
        monoisotopic_mass=28.990164,
        average_mass=29.0,
        dict_composition={'H': -1, 'N': 1, 'O': 1},
    ),
        "AA0231": ResidInfo(
        id="AA0231",
        name="N4-(ADP-ribosyl)-L-asparagine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
        "AA0232": ResidInfo(
        id="AA0232",
        name="L-beta-methylthioaspartic acid",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.09,
        dict_composition={'C': 1, 'H': 2, 'S': 1},
    ),
        "AA0233": ResidInfo(
        id="AA0233",
        name="5'-(N6-L-lysine)-L-topaquinone",
        formula="H-4O",
        monoisotopic_mass=11.963614,
        average_mass=11.97,
        dict_composition={'H': -4, 'O': 1},
    ),
        "AA0234": ResidInfo(
        id="AA0234",
        name="S-methyl-L-cysteine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0235": ResidInfo(
        id="AA0235",
        name="4-hydroxy-L-lysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0236": ResidInfo(
        id="AA0236",
        name="N4-hydroxymethyl-L-asparagine",
        formula="CH2O",
        monoisotopic_mass=30.010565,
        average_mass=30.03,
        dict_composition={'C': 1, 'H': 2, 'O': 1},
    ),
        "AA0237": ResidInfo(
        id="AA0237",
        name="O-(ADP-ribosyl)-L-serine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
        "AA0238": ResidInfo(
        id="AA0238",
        name="L-cysteine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0239": ResidInfo(
        id="AA0239",
        name="L-cysteine oxazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0240": ResidInfo(
        id="AA0240",
        name="glycine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0241": ResidInfo(
        id="AA0241",
        name="glycine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0242": ResidInfo(
        id="AA0242",
        name="L-serine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0243": ResidInfo(
        id="AA0243",
        name="L-phenylalanine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0244": ResidInfo(
        id="AA0244",
        name="L-cysteine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0245": ResidInfo(
        id="AA0245",
        name="L-lysine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0250": ResidInfo(
        id="AA0250",
        name="3-(3'-L-histidyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0251": ResidInfo(
        id="AA0251",
        name="L-methionine sulfone",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0252": ResidInfo(
        id="AA0252",
        name="dipyrrolylmethanemethyl-L-cysteine",
        formula="C20H22N2O8",
        monoisotopic_mass=418.137616,
        average_mass=418.4,
        dict_composition={'C': 20, 'H': 22, 'N': 2, 'O': 8},
    ),
        "AA0253": ResidInfo(
        id="AA0253",
        name="S-(2-aminovinyl)-3-methyl-D-cysteine",
        formula="C-1H-4O-3",
        monoisotopic_mass=-64.016044,
        average_mass=-64.04,
        dict_composition={'C': -1, 'H': -4, 'O': -3},
    ),
        "AA0255": ResidInfo(
        id="AA0255",
        name="O-(phospho-5'-DNA)-L-threonine",
        formula="O3P",
        monoisotopic_mass=78.958505,
        average_mass=78.97,
        dict_composition={'O': 3, 'P': 1},
    ),
        "AA0256": ResidInfo(
        id="AA0256",
        name="O4'-(phospho-5'-uridine)-L-tyrosine",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 8, 'P': 1},
    ),
        "AA0257": ResidInfo(
        id="AA0257",
        name="N-(L-glutamyl)-L-tyrosine",
        formula="H-1O-1",
        monoisotopic_mass=-17.00274,
        average_mass=-17.01,
        dict_composition={'H': -1, 'O': -1},
    ),
        "AA0258": ResidInfo(
        id="AA0258",
        name="S-phycoviolobilin-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
        "AA0259": ResidInfo(
        id="AA0259",
        name="phycoerythrobilin-bis-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
        "AA0260": ResidInfo(
        id="AA0260",
        name="phycourobilin-bis-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
        "AA0262": ResidInfo(
        id="AA0262",
        name="L-cysteine sulfinic acid",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0263": ResidInfo(
        id="AA0263",
        name="L-3',4',5'-trihydroxyphenylalanine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0264": ResidInfo(
        id="AA0264",
        name="O-(sn-1-glycerophosphoryl)-L-serine",
        formula="C3H7O5P",
        monoisotopic_mass=154.00311,
        average_mass=154.06,
        dict_composition={'C': 3, 'H': 7, 'O': 5, 'P': 1},
    ),
        "AA0266": ResidInfo(
        id="AA0266",
        name="heme P460-bis-L-cysteine-L-tyrosine",
        formula="C34FeH30N4O4",
        monoisotopic_mass=614.161643,
        average_mass=614.48,
        dict_composition={'C': 34, 'Fe': 1, 'H': 30, 'N': 4, 'O': 4},
    ),
        "AA0267": ResidInfo(
        id="AA0267",
        name="O-(phospho-5'-adenosine)-L-threonine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
        "AA0268": ResidInfo(
        id="AA0268",
        name="tris-L-cysteinyl L-cysteine persulfido bis-L-glutamato L-histidino tetrairon disulfide trioxide",
        formula="Fe4H-7O3S3",
        monoisotopic_mass=360.585932,
        average_mass=360.5,
        dict_composition={'Fe': 4, 'H': -7, 'O': 3, 'S': 3},
    ),
        "AA0269": ResidInfo(
        id="AA0269",
        name="L-cysteine persulfide",
        formula="S",
        monoisotopic_mass=31.972071,
        average_mass=32.06,
        dict_composition={'S': 1},
    ),
        "AA0270": ResidInfo(
        id="AA0270",
        name="3'-(1'-L-histidyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0271": ResidInfo(
        id="AA0271",
        name="heme P460-bis-L-cysteine-L-lysine",
        formula="C34FeH30N4O4",
        monoisotopic_mass=614.161643,
        average_mass=614.48,
        dict_composition={'C': 34, 'Fe': 1, 'H': 30, 'N': 4, 'O': 4},
    ),
        "AA0272": ResidInfo(
        id="AA0272",
        name="5-methyl-L-arginine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0273": ResidInfo(
        id="AA0273",
        name="2-methyl-L-glutamine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0274": ResidInfo(
        id="AA0274",
        name="N-pyruvic acid 2-iminyl-L-cysteine",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.05,
        dict_composition={'C': 3, 'H': 2, 'O': 2},
    ),
        "AA0275": ResidInfo(
        id="AA0275",
        name="N-pyruvic acid 2-iminyl-L-valine",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.05,
        dict_composition={'C': 3, 'H': 2, 'O': 2},
    ),
        "AA0276": ResidInfo(
        id="AA0276",
        name="3'-heme-L-histidine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
        "AA0277": ResidInfo(
        id="AA0277",
        name="S-selenyl-L-cysteine",
        formula="Se",
        monoisotopic_mass=79.916521,
        average_mass=78.97,
        dict_composition={'Se': 1},
    ),
        "AA0279": ResidInfo(
        id="AA0279",
        name="dihydroxyheme-L-aspartate ester-L-glutamate ester",
        formula="C34FeH28N4O4",
        monoisotopic_mass=612.145993,
        average_mass=612.47,
        dict_composition={'C': 34, 'Fe': 1, 'H': 28, 'N': 4, 'O': 4},
    ),
        "AA0280": ResidInfo(
        id="AA0280",
        name="dihydroxyheme-L-aspartate ester-L-glutamate ester-L-methionine sulfonium",
        formula="C34FeH29N4O4",
        monoisotopic_mass=613.153269,
        average_mass=613.47,
        dict_composition={'C': 34, 'Fe': 1, 'H': 29, 'N': 4, 'O': 4},
    ),
        "AA0281": ResidInfo(
        id="AA0281",
        name="L-cysteinyl molybdenum bis(molybdopterin guanine dinucleotide)",
        formula="C40H47MoN20O26P4S4",
        monoisotopic_mass=1572.985775,
        average_mass=1572.02,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 26, 'P': 4, 'S': 4},
    ),
        "AA0282": ResidInfo(
        id="AA0282",
        name="(2S,3R,4S)-3,4-dihydroxyproline",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0283": ResidInfo(
        id="AA0283",
        name="pyrroloquinoline quinone",
        formula="H-10O3",
        monoisotopic_mass=37.906494,
        average_mass=37.92,
        dict_composition={'H': -10, 'O': 3},
    ),
        "AA0284": ResidInfo(
        id="AA0284",
        name="tris-L-cysteinyl L-N1'-histidino tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0285": ResidInfo(
        id="AA0285",
        name="tris-L-cysteinyl L-N3'-histidino tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0286": ResidInfo(
        id="AA0286",
        name="tris-L-cysteinyl L-aspartato tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0287": ResidInfo(
        id="AA0287",
        name="N6-pyruvic acid 2-iminyl-L-lysine",
        formula="C3H2O2",
        monoisotopic_mass=70.005479,
        average_mass=70.05,
        dict_composition={'C': 3, 'H': 2, 'O': 2},
    ),
        "AA0288": ResidInfo(
        id="AA0288",
        name="tris-L-cysteinyl L-serinyl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0289": ResidInfo(
        id="AA0289",
        name="bis-L-cysteinyl L-N3'-histidino L-serinyl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.597831,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0290": ResidInfo(
        id="AA0290",
        name="O-octanoyl-L-serine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
        "AA0291": ResidInfo(
        id="AA0291",
        name="O-D-glucuronosyl-L-serine",
        formula="C6H8O6",
        monoisotopic_mass=176.032088,
        average_mass=176.12,
        dict_composition={'C': 6, 'H': 8, 'O': 6},
    ),
        "AA0292": ResidInfo(
        id="AA0292",
        name="tris-L-cysteinyl L-cysteine persulfido bis-L-glutamato L-histidino nickel triiron disulfide trioxide",
        formula="Fe3H-7NiO3S3",
        monoisotopic_mass=362.586337,
        average_mass=363.35,
        dict_composition={'Fe': 3, 'H': -7, 'Ni': 1, 'O': 3, 'S': 3},
    ),
        "AA0293": ResidInfo(
        id="AA0293",
        name="tris-L-cysteinyl L-cysteine persulfido L-glutamato L-histidino L-serinyl nickel triiron disulfide trioxide",
        formula="Fe3H-7NiO3S3",
        monoisotopic_mass=362.586337,
        average_mass=363.35,
        dict_composition={'Fe': 3, 'H': -7, 'Ni': 1, 'O': 3, 'S': 3},
    ),
        "AA0296": ResidInfo(
        id="AA0296",
        name="O-(N-acetylglucosamine-1-phosphoryl)-L-serine",
        formula="C8H14NO8P",
        monoisotopic_mass=283.045703,
        average_mass=283.17,
        dict_composition={'C': 8, 'H': 14, 'N': 1, 'O': 8, 'P': 1},
    ),
        "AA0297": ResidInfo(
        id="AA0297",
        name="O-(phosphoglycosyl-D-mannose-1-phosphoryl)-L-serine",
        formula="C6H11O8P",
        monoisotopic_mass=242.019154,
        average_mass=242.12,
        dict_composition={'C': 6, 'H': 11, 'O': 8, 'P': 1},
    ),
        "AA0298": ResidInfo(
        id="AA0298",
        name="heptakis-L-histidino tetracopper mu4-sulfide hydroxide",
        formula="Cu4H-6OS",
        monoisotopic_mass=293.638425,
        average_mass=296.19,
        dict_composition={'Cu': 4, 'H': -6, 'O': 1, 'S': 1},
    ),
        "AA0299": ResidInfo(
        id="AA0299",
        name="L-leucine methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0300": ResidInfo(
        id="AA0300",
        name="hexakis-L-cysteinyl L-serinyl octairon heptasulfide",
        formula="Fe8H-8S7",
        monoisotopic_mass=663.223042,
        average_mass=663.12,
        dict_composition={'Fe': 8, 'H': -8, 'S': 7},
    ),
        "AA0301": ResidInfo(
        id="AA0301",
        name="residues isobaric at 113.084064 Da",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0302": ResidInfo(
        id="AA0302",
        name="L-aspartimide",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0303": ResidInfo(
        id="AA0303",
        name="L-glutamimide",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0304": ResidInfo(
        id="AA0304",
        name="L-beta-carboxyaspartic acid",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
        "AA0305": ResidInfo(
        id="AA0305",
        name="N5-methyl-L-arginine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0306": ResidInfo(
        id="AA0306",
        name="L-cysteine coenzyme A disulfide",
        formula="C21H34N7O16P3S",
        monoisotopic_mass=765.099559,
        average_mass=765.52,
        dict_composition={'C': 21, 'H': 34, 'N': 7, 'O': 16, 'P': 3, 'S': 1},
    ),
        "AA0307": ResidInfo(
        id="AA0307",
        name="S-myristoyl-L-cysteine",
        formula="C14H26O",
        monoisotopic_mass=210.198365,
        average_mass=210.36,
        dict_composition={'C': 14, 'H': 26, 'O': 1},
    ),
        "AA0308": ResidInfo(
        id="AA0308",
        name="S-palmitoleyl-L-cysteine",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
        "AA0309": ResidInfo(
        id="AA0309",
        name="glycine cholesterol ester",
        formula="C27H44",
        monoisotopic_mass=368.344301,
        average_mass=368.65,
        dict_composition={'C': 27, 'H': 44},
    ),
        "AA0310": ResidInfo(
        id="AA0310",
        name="pentakis-L-cysteinyl L-histidino nickel tetrairon pentasulfide",
        formula="Fe4H-6NiS5",
        monoisotopic_mass=435.488498,
        average_mass=436.33,
        dict_composition={'Fe': 4, 'H': -6, 'Ni': 1, 'S': 5},
    ),
        "AA0311": ResidInfo(
        id="AA0311",
        name="N4,N4-dimethyl-L-asparagine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0312": ResidInfo(
        id="AA0312",
        name="N6-3,4-didehydroretinylidene-L-lysine",
        formula="C20H24",
        monoisotopic_mass=264.187801,
        average_mass=264.41,
        dict_composition={'C': 20, 'H': 24},
    ),
        "AA0313": ResidInfo(
        id="AA0313",
        name="4'-(S-L-cysteinyl)-L-tryptophyl quinone",
        formula="H-4O2",
        monoisotopic_mass=27.958529,
        average_mass=27.97,
        dict_composition={'H': -4, 'O': 2},
    ),
        "AA0314": ResidInfo(
        id="AA0314",
        name="3-(S-L-cysteinyl)-L-aspartic acid",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0315": ResidInfo(
        id="AA0315",
        name="4-(S-L-cysteinyl)-L-glutamic acid",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0316": ResidInfo(
        id="AA0316",
        name="cis-14-hydroxy-10,13-dioxo-7-heptadecenoic acid L-aspartate ester",
        formula="C17H26O4",
        monoisotopic_mass=294.183109,
        average_mass=294.39,
        dict_composition={'C': 17, 'H': 26, 'O': 4},
    ),
        "AA0317": ResidInfo(
        id="AA0317",
        name="1'-methyl-L-histidine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0318": ResidInfo(
        id="AA0318",
        name="L-lysine methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0319": ResidInfo(
        id="AA0319",
        name="L-serinyl molybdenum bis(molybdopterin guanine dinucleotide)",
        formula="C40H47MoN20O27P4S4",
        monoisotopic_mass=1588.98069,
        average_mass=1588.01,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 27, 'P': 4, 'S': 4},
    ),
        "AA0320": ResidInfo(
        id="AA0320",
        name="L-beta-methylthioasparagine",
        formula="CH2S",
        monoisotopic_mass=45.987721,
        average_mass=46.09,
        dict_composition={'C': 1, 'H': 2, 'S': 1},
    ),
        "AA0322": ResidInfo(
        id="AA0322",
        name="3-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0324": ResidInfo(
        id="AA0324",
        name="hydroxyheme-L-glutamate ester",
        formula="C34FeH30N4O4",
        monoisotopic_mass=614.161643,
        average_mass=614.48,
        dict_composition={'C': 34, 'Fe': 1, 'H': 30, 'N': 4, 'O': 4},
    ),
        "AA0325": ResidInfo(
        id="AA0325",
        name="(phospho-5'-guanosine)-L-histidine",
        formula="C10H12N5O7P",
        monoisotopic_mass=345.047434,
        average_mass=345.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 7, 'P': 1},
    ),
        "AA0326": ResidInfo(
        id="AA0326",
        name="tetrakis-L-cysteinyl triiron tetrasulfide",
        formula="Fe3H-4S4",
        monoisotopic_mass=291.663442,
        average_mass=291.74,
        dict_composition={'Fe': 3, 'H': -4, 'S': 4},
    ),
        "AA0328": ResidInfo(
        id="AA0328",
        name="(3-aminopropyl)(L-aspartyl-1-amino)phosphoryl-5'-adenosine",
        formula="C13H19N6O6P",
        monoisotopic_mass=386.110369,
        average_mass=386.3,
        dict_composition={'C': 13, 'H': 19, 'N': 6, 'O': 6, 'P': 1},
    ),
        "AA0329": ResidInfo(
        id="AA0329",
        name="1'-heme-L-histidine",
        formula="C34FeH32N4O4",
        monoisotopic_mass=616.177293,
        average_mass=616.5,
        dict_composition={'C': 34, 'Fe': 1, 'H': 32, 'N': 4, 'O': 4},
    ),
        "AA0330": ResidInfo(
        id="AA0330",
        name="(2S,3S,2'R)-3-methyllanthionine sulfoxide",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0331": ResidInfo(
        id="AA0331",
        name="tris-L-cysteinyl L-aspartato diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
        "AA0332": ResidInfo(
        id="AA0332",
        name="S-carbamoyl-L-cysteine",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.02,
        dict_composition={'C': 1, 'H': 1, 'N': 1, 'O': 1},
    ),
        "AA0333": ResidInfo(
        id="AA0333",
        name="S-cyano-L-cysteine",
        formula="CH-1N",
        monoisotopic_mass=24.995249,
        average_mass=25.01,
        dict_composition={'C': 1, 'H': -1, 'N': 1},
    ),
        "AA0334": ResidInfo(
        id="AA0334",
        name="L-cysteinyl hydrogenase diiron subcluster",
        formula="C5Fe2H-1N2O5S2",
        monoisotopic_mass=342.786913,
        average_mass=342.87,
        dict_composition={'C': 5, 'Fe': 2, 'H': -1, 'N': 2, 'O': 5, 'S': 2},
    ),
        "AA0335": ResidInfo(
        id="AA0335",
        name="S-amidino-L-cysteine",
        formula="CH2N2",
        monoisotopic_mass=42.021798,
        average_mass=42.04,
        dict_composition={'C': 1, 'H': 2, 'N': 2},
    ),
        "AA0336": ResidInfo(
        id="AA0336",
        name="N-methyl-L-isoleucine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0337": ResidInfo(
        id="AA0337",
        name="N-methyl-L-leucine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0338": ResidInfo(
        id="AA0338",
        name="N-methyl-L-tyrosine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0339": ResidInfo(
        id="AA0339",
        name="N-palmitoylglycine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
        "AA0340": ResidInfo(
        id="AA0340",
        name="2-(S-L-cysteinyl)-L-phenylalanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0341": ResidInfo(
        id="AA0341",
        name="2-(S-L-cysteinyl)-D-phenylalanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0342": ResidInfo(
        id="AA0342",
        name="2-(S-L-cysteinyl)-D-allo-threonine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0343": ResidInfo(
        id="AA0343",
        name="N-carbamoyl-L-alanine",
        formula="CHNO",
        monoisotopic_mass=43.005814,
        average_mass=43.02,
        dict_composition={'C': 1, 'H': 1, 'N': 1, 'O': 1},
    ),
        "AA0344": ResidInfo(
        id="AA0344",
        name="4-amino-3-isothiazolidinone-L-serine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0346": ResidInfo(
        id="AA0346",
        name="N-glycyl-1-(phosphatidyl)ethanolamine",
        formula="C39H74NO7P",
        monoisotopic_mass=699.52029,
        average_mass=699.99,
        dict_composition={'C': 39, 'H': 74, 'N': 1, 'O': 7, 'P': 1},
    ),
        "AA0347": ResidInfo(
        id="AA0347",
        name="L-glutamyl 5-omega-hydroxyceramide ester",
        formula="C50H96O4",
        monoisotopic_mass=760.730862,
        average_mass=761.31,
        dict_composition={'C': 50, 'H': 96, 'O': 4},
    ),
        "AA0348": ResidInfo(
        id="AA0348",
        name="S-[5'-(L-tryptoph-6'-yl)-L-tyrosin-3'-yl]-L-methionin-S-ium",
        formula="H-3",
        monoisotopic_mass=-3.024024,
        average_mass=-3.02,
        dict_composition={'H': -3},
    ),
        "AA0349": ResidInfo(
        id="AA0349",
        name="O-(riboflavin phosphoryl)-L-threonine",
        formula="C17H19N4O8P",
        monoisotopic_mass=438.09405,
        average_mass=438.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 8, 'P': 1},
    ),
        "AA0350": ResidInfo(
        id="AA0350",
        name="O-(riboflavin phosphoryl)-L-serine",
        formula="C17H19N4O8P",
        monoisotopic_mass=438.09405,
        average_mass=438.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 8, 'P': 1},
    ),
        "AA0351": ResidInfo(
        id="AA0351",
        name="S-(4alpha-FMN)-L-cysteine",
        formula="C17H21N4O9P",
        monoisotopic_mass=456.104615,
        average_mass=456.35,
        dict_composition={'C': 17, 'H': 21, 'N': 4, 'O': 9, 'P': 1},
    ),
        "AA0352": ResidInfo(
        id="AA0352",
        name="1'-(8alpha-FMN)-L-histidine",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
        "AA0353": ResidInfo(
        id="AA0353",
        name="3'-(8alpha-FMN)-L-histidine",
        formula="C17H19N4O9P",
        monoisotopic_mass=454.088965,
        average_mass=454.33,
        dict_composition={'C': 17, 'H': 19, 'N': 4, 'O': 9, 'P': 1},
    ),
        "AA0354": ResidInfo(
        id="AA0354",
        name="N2-acetyl-L-arginine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0355": ResidInfo(
        id="AA0355",
        name="L-cysteinyl copper sulfido molybdopterin cytosine dinuncleotide",
        formula="C19CuH24MoN8O15P2S3",
        monoisotopic_mass=922.834854,
        average_mass=922.07,
        dict_composition={'C': 19, 'Cu': 1, 'H': 24, 'Mo': 1, 'N': 8, 'O': 15, 'P': 2, 'S': 3},
    ),
        "AA0356": ResidInfo(
        id="AA0356",
        name="tris-L-cysteinyl S-adenosylmethion-N,O-diyl tetrairon tetrasulfide",
        formula="C15Fe4H19N6O5S5",
        monoisotopic_mass=746.742346,
        average_mass=747.03,
        dict_composition={'C': 15, 'Fe': 4, 'H': 19, 'N': 6, 'O': 5, 'S': 5},
    ),
        "AA0357": ResidInfo(
        id="AA0357",
        name="tris-L-cysteinyl L-arginyl diiron disulfide",
        formula="Fe2H-3S2",
        monoisotopic_mass=172.791639,
        average_mass=172.79,
        dict_composition={'Fe': 2, 'H': -3, 'S': 2},
    ),
        "AA0359": ResidInfo(
        id="AA0359",
        name="5-hydroxy-N6,N6,N6-trimethyl-L-lysine",
        formula="C3H7O",
        monoisotopic_mass=59.049141,
        average_mass=59.09,
        dict_composition={'C': 3, 'H': 7, 'O': 1},
    ),
        "AA0360": ResidInfo(
        id="AA0360",
        name="N-(L-isoglutamyl)-glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0361": ResidInfo(
        id="AA0361",
        name="O-sulfo-L-serine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
        "AA0362": ResidInfo(
        id="AA0362",
        name="O-sulfo-L-threonine",
        formula="O3S",
        monoisotopic_mass=79.956815,
        average_mass=80.06,
        dict_composition={'O': 3, 'S': 1},
    ),
        "AA0363": ResidInfo(
        id="AA0363",
        name="N-carboxy-L-methionine",
        formula="CO2",
        monoisotopic_mass=43.989829,
        average_mass=44.01,
        dict_composition={'C': 1, 'O': 2},
    ),
        "AA0365": ResidInfo(
        id="AA0365",
        name="(E)-2,3-didehydrotyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0366": ResidInfo(
        id="AA0366",
        name="bis-L-aspartato tris-L-glutamato L-histidino calcium tetramanganese tetroxide",
        formula="CaH-6Mn4O4",
        monoisotopic_mass=317.64748,
        average_mass=317.78,
        dict_composition={'Ca': 1, 'H': -6, 'Mn': 4, 'O': 4},
    ),
        "AA0367": ResidInfo(
        id="AA0367",
        name="3'-(3'-L-tyrosinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0368": ResidInfo(
        id="AA0368",
        name="3'-(O4'-L-tyrosinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0369": ResidInfo(
        id="AA0369",
        name="3,4-dihydroxy-L-arginine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0370": ResidInfo(
        id="AA0370",
        name="4,5-dihydroxy-L-lysine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0371": ResidInfo(
        id="AA0371",
        name="1'-(phospho-5'-adenosine)-L-histidine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
        "AA0372": ResidInfo(
        id="AA0372",
        name="1'-(phospho-5'-uridine)-L-histidine",
        formula="C9H11N2O8P",
        monoisotopic_mass=306.025302,
        average_mass=306.17,
        dict_composition={'C': 9, 'H': 11, 'N': 2, 'O': 8, 'P': 1},
    ),
        "AA0373": ResidInfo(
        id="AA0373",
        name="L-aspartyl semialdehyde",
        formula="O-1",
        monoisotopic_mass=-15.994915,
        average_mass=-16.0,
        dict_composition={'O': -1},
    ),
        "AA0374": ResidInfo(
        id="AA0374",
        name="L-serine microcin E492 siderophore ester",
        formula="C36H37N3O20",
        monoisotopic_mass=831.197041,
        average_mass=831.69,
        dict_composition={'C': 36, 'H': 37, 'N': 3, 'O': 20},
    ),
        "AA0375": ResidInfo(
        id="AA0375",
        name="L-aspartyl molybdenum bis(molybdopterin guanine dinucleotide)",
        formula="C40H47MoN20O26P4S4",
        monoisotopic_mass=1572.985775,
        average_mass=1572.02,
        dict_composition={'C': 40, 'H': 47, 'Mo': 1, 'N': 20, 'O': 26, 'P': 4, 'S': 4},
    ),
        "AA0377": ResidInfo(
        id="AA0377",
        name="3-(2-methylthio)ethyl-6-(4-hydroxybenzylidene)-5-iminopiperazin-2-one",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0378": ResidInfo(
        id="AA0378",
        name="2-imino-glutamic acid 5-imidazolinone glycine",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0379": ResidInfo(
        id="AA0379",
        name="2-imino-methionine 5-imidazolinone glycine",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0380": ResidInfo(
        id="AA0380",
        name="L-asparagine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0381": ResidInfo(
        id="AA0381",
        name="L-lysine 5-imidazolinone glycine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0382": ResidInfo(
        id="AA0382",
        name="2-tetrahydropyridinyl-5-imidazolinone glycine",
        formula="H-7N-1O-1",
        monoisotopic_mass=-37.052764,
        average_mass=-37.06,
        dict_composition={'H': -7, 'N': -1, 'O': -1},
    ),
        "AA0384": ResidInfo(
        id="AA0384",
        name="N-formyl-L-proline",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
        "AA0385": ResidInfo(
        id="AA0385",
        name="O-decanoyl-L-serine",
        formula="C10H18O",
        monoisotopic_mass=154.135765,
        average_mass=154.25,
        dict_composition={'C': 10, 'H': 18, 'O': 1},
    ),
        "AA0386": ResidInfo(
        id="AA0386",
        name="O-octanoyl-L-threonine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
        "AA0387": ResidInfo(
        id="AA0387",
        name="O-decanoyl-L-threonine",
        formula="C10H18O",
        monoisotopic_mass=154.135765,
        average_mass=154.25,
        dict_composition={'C': 10, 'H': 18, 'O': 1},
    ),
        "AA0556": ResidInfo(
        id="AA0556",
        name="L-cysteic acid (L-cysteine sulfonic acid)",
        formula="O3",
        monoisotopic_mass=47.984744,
        average_mass=48.0,
        dict_composition={'O': 3},
    ),
        "AA0200": ResidInfo(
        id="AA0200",
        name="D-valine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0388": ResidInfo(
        id="AA0388",
        name="4-hydroxy-D-valine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0389": ResidInfo(
        id="AA0389",
        name="O4-galactosyl-L-hydroxyproline",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'C': 6, 'H': 10, 'O': 6},
    ),
        "AA0390": ResidInfo(
        id="AA0390",
        name="O4-(N-acetylamino)glucosyl-L-hydroxyproline",
        formula="C8H13NO6",
        monoisotopic_mass=219.074287,
        average_mass=219.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 6},
    ),
        "AA0391": ResidInfo(
        id="AA0391",
        name="2-(S-L-cysteinyl)pyruvic acid O-phosphothioketal",
        formula="C3H5O6P",
        monoisotopic_mass=167.982375,
        average_mass=168.04,
        dict_composition={'C': 3, 'H': 5, 'O': 6, 'P': 1},
    ),
        "AA0392": ResidInfo(
        id="AA0392",
        name="S-galactosyl-L-cysteine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0393": ResidInfo(
        id="AA0393",
        name="L-cysteinyl-L-histidino-homocitryl vanadium heptairon nonasulfide",
        formula="C7Fe7H6O7S9V",
        monoisotopic_mass=932.248513,
        average_mass=932.51,
        dict_composition={'C': 7, 'Fe': 7, 'H': 6, 'O': 7, 'S': 9, 'V': 1},
    ),
        "AA0394": ResidInfo(
        id="AA0394",
        name="L-cysteinyl-L-histidino-homocitryl octairon nonasulfide",
        formula="C7Fe8H6O7S9",
        monoisotopic_mass=937.240588,
        average_mass=937.42,
        dict_composition={'C': 7, 'Fe': 8, 'H': 6, 'O': 7, 'S': 9},
    ),
        "AA0395": ResidInfo(
        id="AA0395",
        name="L-histidino vanadium tetraoxide",
        formula="H2O4V",
        monoisotopic_mass=116.939268,
        average_mass=116.95,
        dict_composition={'H': 2, 'O': 4, 'V': 1},
    ),
        "AA0396": ResidInfo(
        id="AA0396",
        name="3-(S-L-cysteinyl)-L-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0397": ResidInfo(
        id="AA0397",
        name="O-glucosyl-L-serine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0398": ResidInfo(
        id="AA0398",
        name="O-(N-acetylamino)glucosyl-L-serine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0399": ResidInfo(
        id="AA0399",
        name="O-(N-acetylamino)glucosyl-L-threonine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0400": ResidInfo(
        id="AA0400",
        name="O-galactosyl-L-serine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0401": ResidInfo(
        id="AA0401",
        name="O-galactosyl-L-threonine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0402": ResidInfo(
        id="AA0402",
        name="O-mannosyl-L-serine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0403": ResidInfo(
        id="AA0403",
        name="O-mannosyl-L-threonine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0404": ResidInfo(
        id="AA0404",
        name="O-fucosyl-L-serine",
        formula="C6H10O4",
        monoisotopic_mass=146.057909,
        average_mass=146.14,
        dict_composition={'C': 6, 'H': 10, 'O': 4},
    ),
        "AA0405": ResidInfo(
        id="AA0405",
        name="O-fucosyl-L-threonine",
        formula="C6H10O4",
        monoisotopic_mass=146.057909,
        average_mass=146.14,
        dict_composition={'C': 6, 'H': 10, 'O': 4},
    ),
        "AA0406": ResidInfo(
        id="AA0406",
        name="O-xylosyl-L-serine",
        formula="C5H8O4",
        monoisotopic_mass=132.042259,
        average_mass=132.12,
        dict_composition={'C': 5, 'H': 8, 'O': 4},
    ),
        "AA0407": ResidInfo(
        id="AA0407",
        name="S-stearoyl-L-cysteine",
        formula="C18H34O",
        monoisotopic_mass=266.260966,
        average_mass=266.47,
        dict_composition={'C': 18, 'H': 34, 'O': 1},
    ),
        "AA0408": ResidInfo(
        id="AA0408",
        name="3'-geranyl-2',3'-dihydro-2',N2-cyclo-L-tryptophan",
        formula="C10H16",
        monoisotopic_mass=136.125201,
        average_mass=136.24,
        dict_composition={'C': 10, 'H': 16},
    ),
        "AA0409": ResidInfo(
        id="AA0409",
        name="L-2-aminobutanoic acid (Glu)",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
        "AA0410": ResidInfo(
        id="AA0410",
        name="2-imino-alanine 5-imidazolinone glycine",
        formula="C-1H-4O-3",
        monoisotopic_mass=-64.016044,
        average_mass=-64.04,
        dict_composition={'C': -1, 'H': -4, 'O': -3},
    ),
        "AA0411": ResidInfo(
        id="AA0411",
        name="S-(L-alanyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0412": ResidInfo(
        id="AA0412",
        name="S-(L-leucyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0413": ResidInfo(
        id="AA0413",
        name="S-(L-methionyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0414": ResidInfo(
        id="AA0414",
        name="S-(L-phenylalanyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0415": ResidInfo(
        id="AA0415",
        name="S-(L-threonyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0416": ResidInfo(
        id="AA0416",
        name="S-(L-tyrosyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0417": ResidInfo(
        id="AA0417",
        name="S-(L-tryptophanyl)-L-cysteine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0418": ResidInfo(
        id="AA0418",
        name="O-(L-phenylalanyl)-L-serine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0419": ResidInfo(
        id="AA0419",
        name="N-methyl-L-proline",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0420": ResidInfo(
        id="AA0420",
        name="N4-(N-acetylamino)galactosyl-L-asparagine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0421": ResidInfo(
        id="AA0421",
        name="N4-glucosyl-L-asparagine",
        formula="C6H10O5",
        monoisotopic_mass=162.052823,
        average_mass=162.14,
        dict_composition={'C': 6, 'H': 10, 'O': 5},
    ),
        "AA0422": ResidInfo(
        id="AA0422",
        name="O-(N-acetylamino)fucosyl-L-serine",
        formula="C8H13NO4",
        monoisotopic_mass=187.084458,
        average_mass=187.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 4},
    ),
        "AA0199": ResidInfo(
        id="AA0199",
        name="D-allo-threonine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0438": ResidInfo(
        id="AA0438",
        name="tris-L-cysteinyl L-histidino diiron disulfide",
        formula="Fe2H-4S2",
        monoisotopic_mass=171.783814,
        average_mass=171.78,
        dict_composition={'Fe': 2, 'H': -4, 'S': 2},
    ),
        "AA0439": ResidInfo(
        id="AA0439",
        name="N-aspartyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0180": ResidInfo(
        id="AA0180",
        name="6'-chloro-L-tryptophan",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
        "AA0440": ResidInfo(
        id="AA0440",
        name="N6-(L-threonyl)-L-lysine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0428": ResidInfo(
        id="AA0428",
        name="S-15,16-dihydrobiliverdin-L-cysteine",
        formula="C33H36N4O6",
        monoisotopic_mass=584.263485,
        average_mass=584.67,
        dict_composition={'C': 33, 'H': 36, 'N': 4, 'O': 6},
    ),
        "AA0429": ResidInfo(
        id="AA0429",
        name="15,16-dihydrobiliverdin-bis-L-cysteine",
        formula="C33H36N4O6",
        monoisotopic_mass=584.263485,
        average_mass=584.67,
        dict_composition={'C': 33, 'H': 36, 'N': 4, 'O': 6},
    ),
        "AA0423": ResidInfo(
        id="AA0423",
        name="O-acetyl-L-threonine",
        formula="C2H2O",
        monoisotopic_mass=42.010565,
        average_mass=42.04,
        dict_composition={'C': 2, 'H': 2, 'O': 1},
    ),
        "AA0424": ResidInfo(
        id="AA0424",
        name="N-alanyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0425": ResidInfo(
        id="AA0425",
        name="N-asparaginyl-glycosylsphingolipidinositolethanolamine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0426": ResidInfo(
        id="AA0426",
        name="S-(15-deoxy-Delta12,14-prostaglandin J2-9-yl)-L-cysteine",
        formula="C20H28O3",
        monoisotopic_mass=316.203845,
        average_mass=316.44,
        dict_composition={'C': 20, 'H': 28, 'O': 3},
    ),
        "AA0427": ResidInfo(
        id="AA0427",
        name="S-phycourobilin-L-cysteine",
        formula="C33H38N4O6",
        monoisotopic_mass=586.279135,
        average_mass=586.69,
        dict_composition={'C': 33, 'H': 38, 'N': 4, 'O': 6},
    ),
        "AA0430": ResidInfo(
        id="AA0430",
        name="L-dehydrolysinonorleucine",
        formula="H-5N-1",
        monoisotopic_mass=-19.042199,
        average_mass=-19.05,
        dict_composition={'H': -5, 'N': -1},
    ),
        "AA0431": ResidInfo(
        id="AA0431",
        name="1'-(1,2,3-trihydroxyprop-2-yl)-L-histidine",
        formula="C3H6O3",
        monoisotopic_mass=90.031694,
        average_mass=90.08,
        dict_composition={'C': 3, 'H': 6, 'O': 3},
    ),
        "AA0432": ResidInfo(
        id="AA0432",
        name="S-(aspart-4-yloxy) thiocarbonate",
        formula="CO2S",
        monoisotopic_mass=75.9619,
        average_mass=76.07,
        dict_composition={'C': 1, 'O': 2, 'S': 1},
    ),
        "AA0433": ResidInfo(
        id="AA0433",
        name="N,N-dimethyl-L-alanine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0434": ResidInfo(
        id="AA0434",
        name="2-hydroxyglycine observational artifact",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0435": ResidInfo(
        id="AA0435",
        name="L-aspartic acid 4-methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0436": ResidInfo(
        id="AA0436",
        name="6-(S-L-cysteinyl)-8alpha-(-3'-L-histidino)-FAD",
        formula="C27H29N9O15P2",
        monoisotopic_mass=781.125835,
        average_mass=781.52,
        dict_composition={'C': 27, 'H': 29, 'N': 9, 'O': 15, 'P': 2},
    ),
        "AA0442": ResidInfo(
        id="AA0442",
        name="(2S)-4-hydroxyleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0443": ResidInfo(
        id="AA0443",
        name="(2S,4R)-5-hydroxyleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0444": ResidInfo(
        id="AA0444",
        name="(2S,4R)-5-oxoleucine",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
        "AA0445": ResidInfo(
        id="AA0445",
        name="(2S,4R)-4,5-dihydroxyleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0447": ResidInfo(
        id="AA0447",
        name="(2S,3S,4R)-3,4-dihydroxyisoleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0448": ResidInfo(
        id="AA0448",
        name="(2S,3R,4S)-4-hydroxyisoleucine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0449": ResidInfo(
        id="AA0449",
        name="(2S,3R,4R)-4,5-dihydroxyisoleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0450": ResidInfo(
        id="AA0450",
        name="2'-methylsulfonyl-L-tryptophan",
        formula="CH2O2S",
        monoisotopic_mass=77.97755,
        average_mass=78.09,
        dict_composition={'C': 1, 'H': 2, 'O': 2, 'S': 1},
    ),
        "AA0451": ResidInfo(
        id="AA0451",
        name="2'-(S-L-cysteinyl)-6'-hydroxy-L-tryptophan sulfoxide",
        formula="H-2O2",
        monoisotopic_mass=29.974179,
        average_mass=29.98,
        dict_composition={'H': -2, 'O': 2},
    ),
        "AA0455": ResidInfo(
        id="AA0455",
        name="O-palmitoleyl-L-serine",
        formula="C16H28O",
        monoisotopic_mass=236.214016,
        average_mass=236.4,
        dict_composition={'C': 16, 'H': 28, 'O': 1},
    ),
        "AA0456": ResidInfo(
        id="AA0456",
        name="N,N,N-trimethyl-L-methionine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
        "AA0457": ResidInfo(
        id="AA0457",
        name="L-cystine S-oxide",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
        "AA0458": ResidInfo(
        id="AA0458",
        name="aminomalonic acid (Ser)",
        formula="H-2O",
        monoisotopic_mass=13.979265,
        average_mass=13.98,
        dict_composition={'H': -2, 'O': 1},
    ),
        "AA0462": ResidInfo(
        id="AA0462",
        name="3-hydroxy-L-phenylalanine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0463": ResidInfo(
        id="AA0463",
        name="3-hydroxy-L-valine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0464": ResidInfo(
        id="AA0464",
        name="O-methyl-L-threonine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0465": ResidInfo(
        id="AA0465",
        name="1-amino-2-propanol",
        formula="C-1O-2",
        monoisotopic_mass=-43.989829,
        average_mass=-44.01,
        dict_composition={'C': -1, 'O': -2},
    ),
        "AA0466": ResidInfo(
        id="AA0466",
        name="L-isoleucine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0467": ResidInfo(
        id="AA0467",
        name="L-valine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0468": ResidInfo(
        id="AA0468",
        name="L-valine 5-(methoxymethyl)thiazole-4-carboxylic acid",
        formula="C2",
        monoisotopic_mass=24.0,
        average_mass=24.02,
        dict_composition={'C': 2},
    ),
        "AA0469": ResidInfo(
        id="AA0469",
        name="L-asparagine 5-methylthiazole-4-carboxylic acid",
        formula="CH-2O-1",
        monoisotopic_mass=-6.010565,
        average_mass=-6.0,
        dict_composition={'C': 1, 'H': -2, 'O': -1},
    ),
        "AA0470": ResidInfo(
        id="AA0470",
        name="L-cysteine pyridine-2,5-dicarboxylic acid",
        formula="H-8N-1O-3",
        monoisotopic_mass=-70.050418,
        average_mass=-70.07,
        dict_composition={'H': -8, 'N': -1, 'O': -3},
    ),
        "AA0471": ResidInfo(
        id="AA0471",
        name="L-cysteine 5-amino-3,4,5,6-tetrahydropyridine-2,5-dicarboxylic acid",
        formula="H-5O-3",
        monoisotopic_mass=-53.023869,
        average_mass=-53.04,
        dict_composition={'H': -5, 'O': -3},
    ),
        "AA0472": ResidInfo(
        id="AA0472",
        name="4-(1-hydroxyethyl)-7-isoleucino-2-(threonin-O3-ylcarbonyl)-7,8-dihydroquinolin-8-ol",
        formula="C12H9NO3",
        monoisotopic_mass=215.058243,
        average_mass=215.21,
        dict_composition={'C': 12, 'H': 9, 'N': 1, 'O': 3},
    ),
        "AA0474": ResidInfo(
        id="AA0474",
        name="L-serine 5-methyloxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0475": ResidInfo(
        id="AA0475",
        name="N6-propanoyl-L-lysine",
        formula="C3H4O",
        monoisotopic_mass=56.026215,
        average_mass=56.06,
        dict_composition={'C': 3, 'H': 4, 'O': 1},
    ),
        "AA0476": ResidInfo(
        id="AA0476",
        name="N6-(ADP-ribosyl)-L-lysine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
        "AA0478": ResidInfo(
        id="AA0478",
        name="(2S,3S)-3-hydroxyasparagine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0479": ResidInfo(
        id="AA0479",
        name="(2S,3R,4R)-3,4-dihydroxyproline",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0480": ResidInfo(
        id="AA0480",
        name="(2S)-4,5,5'-trihydroxyleucine",
        formula="O3",
        monoisotopic_mass=47.984744,
        average_mass=48.0,
        dict_composition={'O': 3},
    ),
        "AA0481": ResidInfo(
        id="AA0481",
        name="L-asparagine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0482": ResidInfo(
        id="AA0482",
        name="L-proline thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0483": ResidInfo(
        id="AA0483",
        name="L-threonine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0484": ResidInfo(
        id="AA0484",
        name="L-phenylalanine thiazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0485": ResidInfo(
        id="AA0485",
        name="L-threonine thiazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0446": ResidInfo(
        id="AA0446",
        name="(2S,4S)-4,5-dihydroxyleucine",
        formula="O2",
        monoisotopic_mass=31.989829,
        average_mass=32.0,
        dict_composition={'O': 2},
    ),
        "AA0486": ResidInfo(
        id="AA0486",
        name="1-amino-2-propanone",
        formula="C-1H-2O-2",
        monoisotopic_mass=-46.005479,
        average_mass=-46.03,
        dict_composition={'C': -1, 'H': -2, 'O': -2},
    ),
        "AA0487": ResidInfo(
        id="AA0487",
        name="4-hydroxy-L-glutamic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0488": ResidInfo(
        id="AA0488",
        name="2-(cystein-S-ylcarbonyl)-3-methyl-4-(glutam-5-yloxy)methylindole",
        formula="C11H7NO",
        monoisotopic_mass=169.052764,
        average_mass=169.18,
        dict_composition={'C': 11, 'H': 7, 'N': 1, 'O': 1},
    ),
        "AA0490": ResidInfo(
        id="AA0490",
        name="3-(O4'-L-tyrosyl)-L-valine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0491": ResidInfo(
        id="AA0491",
        name="tetrakis-L-glutamato bis-L-N1'-histidino lipid carboxylato manganese iron oxide",
        formula="C14FeH23MnO3",
        monoisotopic_mass=350.038251,
        average_mass=350.12,
        dict_composition={'C': 14, 'Fe': 1, 'H': 23, 'Mn': 1, 'O': 3},
    ),
        "AA0547": ResidInfo(
        id="AA0547",
        name="(E)-dehydrobutyrine (Thr)",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0495": ResidInfo(
        id="AA0495",
        name="O-glycyl-L-serine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0496": ResidInfo(
        id="AA0496",
        name="O-glycyl-L-threonine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0497": ResidInfo(
        id="AA0497",
        name="O-(2-aminoethylphosphoryl)-L-serine",
        formula="C2H6NO3P",
        monoisotopic_mass=123.00853,
        average_mass=123.05,
        dict_composition={'C': 2, 'H': 6, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0498": ResidInfo(
        id="AA0498",
        name="O-cholinephosphoryl-L-serine",
        formula="C5H13NO3P",
        monoisotopic_mass=166.062756,
        average_mass=166.14,
        dict_composition={'C': 5, 'H': 13, 'N': 1, 'O': 3, 'P': 1},
    ),
        "AA0499": ResidInfo(
        id="AA0499",
        name="O-(2,4-diacetamido-2,4-dideoxyglucosyl)-L-serine",
        formula="C10H16N2O5",
        monoisotopic_mass=244.105922,
        average_mass=244.25,
        dict_composition={'C': 10, 'H': 16, 'N': 2, 'O': 5},
    ),
        "AA0500": ResidInfo(
        id="AA0500",
        name="3'-farnesyl-2',3'-dihydro-2',N2-cyclo-L-tryptophan",
        formula="C15H24",
        monoisotopic_mass=204.187801,
        average_mass=204.36,
        dict_composition={'C': 15, 'H': 24},
    ),
        "AA0501": ResidInfo(
        id="AA0501",
        name="S-(L-lysyl)-L-methionine sulfilimine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0502": ResidInfo(
        id="AA0502",
        name="5-glutamyl 2-aminoadipic acid",
        formula="C6H9NO3",
        monoisotopic_mass=143.058243,
        average_mass=143.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 3},
    ),
        "AA0503": ResidInfo(
        id="AA0503",
        name="5-glutamyl 2-aminoadipic 6-phosphoric anhydride",
        formula="C6H10NO6P",
        monoisotopic_mass=223.024574,
        average_mass=223.12,
        dict_composition={'C': 6, 'H': 10, 'N': 1, 'O': 6, 'P': 1},
    ),
        "AA0504": ResidInfo(
        id="AA0504",
        name="5-glutamyl allysine",
        formula="C6H9NO2",
        monoisotopic_mass=127.063329,
        average_mass=127.14,
        dict_composition={'C': 6, 'H': 9, 'N': 1, 'O': 2},
    ),
        "AA0505": ResidInfo(
        id="AA0505",
        name="N2-(L-isoglutamyl)-L-lysine",
        formula="C6H12N2O",
        monoisotopic_mass=128.094963,
        average_mass=128.18,
        dict_composition={'C': 6, 'H': 12, 'N': 2, 'O': 1},
    ),
        "AA0506": ResidInfo(
        id="AA0506",
        name="7'-hydroxy-2'-alpha-mannosyl-L-tryptophan",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'C': 6, 'H': 10, 'O': 6},
    ),
        "AA0507": ResidInfo(
        id="AA0507",
        name="L-threonine methyl ester",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0508": ResidInfo(
        id="AA0508",
        name="6-(S-L-cysteinyl)-8alpha-(-3'-L-histidino)-FMN",
        formula="C17H17N4O9P",
        monoisotopic_mass=452.073315,
        average_mass=452.32,
        dict_composition={'C': 17, 'H': 17, 'N': 4, 'O': 9, 'P': 1},
    ),
        "AA0509": ResidInfo(
        id="AA0509",
        name="3'-iodo-L-tyrosine",
        formula="H-1I",
        monoisotopic_mass=125.896648,
        average_mass=125.9,
        dict_composition={'H': -1, 'I': 1},
    ),
        "AA0510": ResidInfo(
        id="AA0510",
        name="3',5'-diiodo-L-tyrosine",
        formula="H-2I2",
        monoisotopic_mass=251.793295,
        average_mass=251.79,
        dict_composition={'H': -2, 'I': 2},
    ),
        "AA0511": ResidInfo(
        id="AA0511",
        name="glycyl phospho-5'-adenosine",
        formula="C10H12N5O6P",
        monoisotopic_mass=329.05252,
        average_mass=329.21,
        dict_composition={'C': 10, 'H': 12, 'N': 5, 'O': 6, 'P': 1},
    ),
        "AA0512": ResidInfo(
        id="AA0512",
        name="glycyl cysteine dithioester",
        formula="H-2O-1S",
        monoisotopic_mass=13.961506,
        average_mass=14.05,
        dict_composition={'H': -2, 'O': -1, 'S': 1},
    ),
        "AA0513": ResidInfo(
        id="AA0513",
        name="trithiocystine",
        formula="H-2S3",
        monoisotopic_mass=93.900563,
        average_mass=94.16,
        dict_composition={'H': -2, 'S': 3},
    ),
        "AA0514": ResidInfo(
        id="AA0514",
        name="O-(6-phosphomannosyl)-L-threonine",
        formula="C6H11O8P",
        monoisotopic_mass=242.019154,
        average_mass=242.12,
        dict_composition={'C': 6, 'H': 11, 'O': 8, 'P': 1},
    ),
        "AA0515": ResidInfo(
        id="AA0515",
        name="L-alanyl-L-isoaspartyl cyclopeptide",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
        "AA0518": ResidInfo(
        id="AA0518",
        name="N5-(ADP-ribosyl)-L-glutamine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
        "AA0519": ResidInfo(
        id="AA0519",
        name="O-(ADP-ribosyl)-L-threonine",
        formula="C15H21N5O13P2",
        monoisotopic_mass=541.061109,
        average_mass=541.3,
        dict_composition={'C': 15, 'H': 21, 'N': 5, 'O': 13, 'P': 2},
    ),
        "AA0520": ResidInfo(
        id="AA0520",
        name="7'-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0522": ResidInfo(
        id="AA0522",
        name="O4-(8alpha-FAD)-L-aspartate",
        formula="C27H31N9O15P2",
        monoisotopic_mass=783.141485,
        average_mass=783.54,
        dict_composition={'C': 27, 'H': 31, 'N': 9, 'O': 15, 'P': 2},
    ),
        "AA0523": ResidInfo(
        id="AA0523",
        name="trimethyl-L-arginine",
        formula="C3H6",
        monoisotopic_mass=42.04695,
        average_mass=42.08,
        dict_composition={'C': 3, 'H': 6},
    ),
        "AA0524": ResidInfo(
        id="AA0524",
        name="N6-chloro-L-lysine",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
        "AA0516": ResidInfo(
        id="AA0516",
        name="N-[(12R)-12-hydroxymyristoyl]-L-cysteine",
        formula="C14H26O2",
        monoisotopic_mass=226.19328,
        average_mass=226.36,
        dict_composition={'C': 14, 'H': 26, 'O': 2},
    ),
        "AA0517": ResidInfo(
        id="AA0517",
        name="N-(12-ketomyristoyl)-L-cysteine",
        formula="C14H24O2",
        monoisotopic_mass=224.17763,
        average_mass=224.34,
        dict_composition={'C': 14, 'H': 24, 'O': 2},
    ),
        "AA0526": ResidInfo(
        id="AA0526",
        name="S-(coelenterazin-3a-yl)-L-cysteine",
        formula="C26H19N3O3",
        monoisotopic_mass=421.142641,
        average_mass=421.46,
        dict_composition={'C': 26, 'H': 19, 'N': 3, 'O': 3},
    ),
        "AA0527": ResidInfo(
        id="AA0527",
        name="N6-octanoyl-L-lysine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
        "AA0528": ResidInfo(
        id="AA0528",
        name="5-glutamyl serotonin",
        formula="C10H9NO",
        monoisotopic_mass=159.068414,
        average_mass=159.19,
        dict_composition={'C': 10, 'H': 9, 'N': 1, 'O': 1},
    ),
        "AA0529": ResidInfo(
        id="AA0529",
        name="N-(glycyl)-L-cysteine",
        formula="C3H5NOS",
        monoisotopic_mass=103.009185,
        average_mass=103.14,
        dict_composition={'C': 3, 'H': 5, 'N': 1, 'O': 1, 'S': 1},
    ),
        "AA0530": ResidInfo(
        id="AA0530",
        name="N6-(L-lysyl)-L-lysine",
        formula="C6H12N2O",
        monoisotopic_mass=128.094963,
        average_mass=128.18,
        dict_composition={'C': 6, 'H': 12, 'N': 2, 'O': 1},
    ),
        "AA0531": ResidInfo(
        id="AA0531",
        name="N6-(beta-lysyl)-L-5-hydroxylysine",
        formula="C6H12N2O2",
        monoisotopic_mass=144.089878,
        average_mass=144.17,
        dict_composition={'C': 6, 'H': 12, 'N': 2, 'O': 2},
    ),
        "AA0532": ResidInfo(
        id="AA0532",
        name="N6-butanoyl-L-lysine",
        formula="C4H6O",
        monoisotopic_mass=70.041865,
        average_mass=70.09,
        dict_composition={'C': 4, 'H': 6, 'O': 1},
    ),
        "AA0533": ResidInfo(
        id="AA0533",
        name="N-methyl-L-serine",
        formula="CH2",
        monoisotopic_mass=14.01565,
        average_mass=14.03,
        dict_composition={'C': 1, 'H': 2},
    ),
        "AA0534": ResidInfo(
        id="AA0534",
        name="N,N-dimethyl-L-serine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0535": ResidInfo(
        id="AA0535",
        name="N,N,N-trimethyl-L-serine",
        formula="C3H7",
        monoisotopic_mass=43.054227,
        average_mass=43.09,
        dict_composition={'C': 3, 'H': 7},
    ),
        "AA0537": ResidInfo(
        id="AA0537",
        name="3'-nitro-L-tyrosine",
        formula="H-1NO2",
        monoisotopic_mass=44.985078,
        average_mass=45.0,
        dict_composition={'H': -1, 'N': 1, 'O': 2},
    ),
        "AA0459": ResidInfo(
        id="AA0459",
        name="5'-(L-tyros-5'-yl)amino-L-tyrosine",
        formula="H-1N",
        monoisotopic_mass=12.995249,
        average_mass=13.0,
        dict_composition={'H': -1, 'N': 1},
    ),
        "AA0538": ResidInfo(
        id="AA0538",
        name="N,N-dimethyl-L-leucine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0539": ResidInfo(
        id="AA0539",
        name="N-formyl-L-glutamic acid",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
        "AA0540": ResidInfo(
        id="AA0540",
        name="L-cysteine 3-hydroxy-2,5-pyridinedicarboxylic acid",
        formula="H-8N-1O-2",
        monoisotopic_mass=-54.055504,
        average_mass=-54.07,
        dict_composition={'H': -8, 'N': -1, 'O': -2},
    ),
        "AA0541": ResidInfo(
        id="AA0541",
        name="L-glutamate thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0542": ResidInfo(
        id="AA0542",
        name="2'-hydroxy-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0543": ResidInfo(
        id="AA0543",
        name="2'-oxo-L-tryptophan",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0544": ResidInfo(
        id="AA0544",
        name="1'-(L-tryptophan-3'-yl)-L-tryptophan",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0545": ResidInfo(
        id="AA0545",
        name="N6-succinyl-L-lysine",
        formula="C4H4O3",
        monoisotopic_mass=100.016044,
        average_mass=100.07,
        dict_composition={'C': 4, 'H': 4, 'O': 3},
    ),
        "AA0546": ResidInfo(
        id="AA0546",
        name="L-allo-isoleucine",
        formula=None,
        monoisotopic_mass=0.0,
        average_mass=0.0,
        dict_composition={},
    ),
        "AA0548": ResidInfo(
        id="AA0548",
        name="S-(2-aminovinyl)-L-cysteine",
        formula="C-1H-4O-2S-1",
        monoisotopic_mass=-79.9932,
        average_mass=-80.1,
        dict_composition={'C': -1, 'H': -4, 'O': -2, 'S': -1},
    ),
        "AA0549": ResidInfo(
        id="AA0549",
        name="5'-chloro-L-tryptophan",
        formula="ClH-1",
        monoisotopic_mass=33.961028,
        average_mass=34.44,
        dict_composition={'Cl': 1, 'H': -1},
    ),
        "AA0550": ResidInfo(
        id="AA0550",
        name="2-(3-methylbutanoyl)-5-hydroxyoxazole-4-carbothionic acid",
        formula="H-7N-1O",
        monoisotopic_mass=-5.062935,
        average_mass=-5.06,
        dict_composition={'H': -7, 'N': -1, 'O': 1},
    ),
        "AA0551": ResidInfo(
        id="AA0551",
        name="L-proline 5-hydroxyoxazole-4-carbothionic acid",
        formula="H-4",
        monoisotopic_mass=-4.0313,
        average_mass=-4.03,
        dict_composition={'H': -4},
    ),
        "AA0552": ResidInfo(
        id="AA0552",
        name="methanobactin OB3b copper complex",
        formula="CuH-10O2",
        monoisotopic_mass=84.841176,
        average_mass=85.46,
        dict_composition={'Cu': 1, 'H': -10, 'O': 2},
    ),
        "AA0557": ResidInfo(
        id="AA0557",
        name="L-cysteine sulfinyl phosphate",
        formula="HO5P",
        monoisotopic_mass=111.95616,
        average_mass=111.98,
        dict_composition={'H': 1, 'O': 5, 'P': 1},
    ),
        "AA0558": ResidInfo(
        id="AA0558",
        name="S-(spermidinoglutathion-S-yl)-L-cysteine",
        formula="C17H32N6O5S",
        monoisotopic_mass=432.215489,
        average_mass=432.54,
        dict_composition={'C': 17, 'H': 32, 'N': 6, 'O': 5, 'S': 1},
    ),
        "AA0559": ResidInfo(
        id="AA0559",
        name="2-(L-cystein-S-yl)-methionine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0560": ResidInfo(
        id="AA0560",
        name="S-(N-acetylamino)glucosyl-L-cysteine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0562": ResidInfo(
        id="AA0562",
        name="4-amino-3-isothiazolidinone-L-phenylalanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0563": ResidInfo(
        id="AA0563",
        name="L-cysteine bacillithiol disulfide",
        formula="C13H20N2O10S",
        monoisotopic_mass=396.083866,
        average_mass=396.37,
        dict_composition={'C': 13, 'H': 20, 'N': 2, 'O': 10, 'S': 1},
    ),
        "AA0553": ResidInfo(
        id="AA0553",
        name="2-(4-guanidinobutanoyl)-5-hydroxyimidazole-4-carbothionic acid",
        formula="H-6",
        monoisotopic_mass=-6.04695,
        average_mass=-6.05,
        dict_composition={'H': -6},
    ),
        "AA0554": ResidInfo(
        id="AA0554",
        name="L-threonine 5-hydroxyoxazole-4-carbonthionic acid",
        formula="H-4",
        monoisotopic_mass=-4.0313,
        average_mass=-4.03,
        dict_composition={'H': -4},
    ),
        "AA0555": ResidInfo(
        id="AA0555",
        name="methanobactin SB2 copper complex",
        formula="CuH-9NO",
        monoisotopic_mass=83.857161,
        average_mass=84.48,
        dict_composition={'Cu': 1, 'H': -9, 'N': 1, 'O': 1},
    ),
        "AA0564": ResidInfo(
        id="AA0564",
        name="L-deoxyhypusine",
        formula="C4H9N",
        monoisotopic_mass=71.073499,
        average_mass=71.12,
        dict_composition={'C': 4, 'H': 9, 'N': 1},
    ),
        "AA0565": ResidInfo(
        id="AA0565",
        name="3-(L-phenylalan-2'-yl)-L-valine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0561": ResidInfo(
        id="AA0561",
        name="S-(2-succinyl)-L-cysteine",
        formula="C4H4O4",
        monoisotopic_mass=116.010959,
        average_mass=116.07,
        dict_composition={'C': 4, 'H': 4, 'O': 4},
    ),
        "AA0567": ResidInfo(
        id="AA0567",
        name="N6-crotonyl-L-lysine",
        formula="C4H4O",
        monoisotopic_mass=68.026215,
        average_mass=68.07,
        dict_composition={'C': 4, 'H': 4, 'O': 1},
    ),
        "AA0568": ResidInfo(
        id="AA0568",
        name="N6-malonyl-L-lysine",
        formula="C3H2O3",
        monoisotopic_mass=86.000394,
        average_mass=86.05,
        dict_composition={'C': 3, 'H': 2, 'O': 3},
    ),
        "AA0569": ResidInfo(
        id="AA0569",
        name="N2,N2-dimethyl-L-arginine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0570": ResidInfo(
        id="AA0570",
        name="L-arginine thiazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0571": ResidInfo(
        id="AA0571",
        name="L-cysteine 5-methyloxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0572": ResidInfo(
        id="AA0572",
        name="L-threonine 5-methyloxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0573": ResidInfo(
        id="AA0573",
        name="L-isoleucine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0574": ResidInfo(
        id="AA0574",
        name="L-serine oxazole-4-carboxylic acid",
        formula="H-4O-1",
        monoisotopic_mass=-20.026215,
        average_mass=-20.03,
        dict_composition={'H': -4, 'O': -1},
    ),
        "AA0575": ResidInfo(
        id="AA0575",
        name="L-serine 5-methyloxazoline-4-carboxylic acid",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0576": ResidInfo(
        id="AA0576",
        name="N-formyl-L-alanine",
        formula="CO",
        monoisotopic_mass=27.994915,
        average_mass=28.01,
        dict_composition={'C': 1, 'O': 1},
    ),
        "AA0577": ResidInfo(
        id="AA0577",
        name="O4'-(N-acetylamino)galactosyl-L-tyrosine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0578": ResidInfo(
        id="AA0578",
        name="(2S,5S)-5-hydroxylysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0579": ResidInfo(
        id="AA0579",
        name="(2S,3S)-3-hydroxyaspartic acid",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0580": ResidInfo(
        id="AA0580",
        name="3-hydroxy-L-histidine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0582": ResidInfo(
        id="AA0582",
        name="3-methoxydehydroalanine",
        formula="C",
        monoisotopic_mass=12.0,
        average_mass=12.01,
        dict_composition={'C': 1},
    ),
        "AA0583": ResidInfo(
        id="AA0583",
        name="N6-(L-aspartyl)-L-lysine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0584": ResidInfo(
        id="AA0584",
        name="S-octanoyl-L-cysteine",
        formula="C8H14O",
        monoisotopic_mass=126.104465,
        average_mass=126.2,
        dict_composition={'C': 8, 'H': 14, 'O': 1},
    ),
        "AA0028": ResidInfo(
        id="AA0028",
        name="(2S,5R)-5-hydroxylysine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0585": ResidInfo(
        id="AA0585",
        name="N6-phospho-L-lysine",
        formula="HO3P",
        monoisotopic_mass=79.966331,
        average_mass=79.98,
        dict_composition={'H': 1, 'O': 3, 'P': 1},
    ),
        "AA0586": ResidInfo(
        id="AA0586",
        name="L-lysinonorleucine",
        formula="H-3N-1",
        monoisotopic_mass=-17.026549,
        average_mass=-17.03,
        dict_composition={'H': -3, 'N': -1},
    ),
        "AA0587": ResidInfo(
        id="AA0587",
        name="desmosine",
        formula="H-16N-3",
        monoisotopic_mass=-58.134971,
        average_mass=-58.15,
        dict_composition={'H': -16, 'N': -3},
    ),
        "AA0588": ResidInfo(
        id="AA0588",
        name="isodesmosine",
        formula="H-16N-3",
        monoisotopic_mass=-58.134971,
        average_mass=-58.15,
        dict_composition={'H': -16, 'N': -3},
    ),
        "AA0589": ResidInfo(
        id="AA0589",
        name="O-glucosyl-L-hydroxylysine",
        formula="C6H10O6",
        monoisotopic_mass=178.047738,
        average_mass=178.14,
        dict_composition={'C': 6, 'H': 10, 'O': 6},
    ),
        "AA0590": ResidInfo(
        id="AA0590",
        name="N6-oleoyl-L-lysine",
        formula="C18H32O",
        monoisotopic_mass=264.245316,
        average_mass=264.45,
        dict_composition={'C': 18, 'H': 32, 'O': 1},
    ),
        "AA0591": ResidInfo(
        id="AA0591",
        name="N-palmitoyl-L-methionine",
        formula="C16H30O",
        monoisotopic_mass=238.229666,
        average_mass=238.41,
        dict_composition={'C': 16, 'H': 30, 'O': 1},
    ),
        "AA0594": ResidInfo(
        id="AA0594",
        name="labionin",
        formula="H-4O-2",
        monoisotopic_mass=-36.021129,
        average_mass=-36.03,
        dict_composition={'H': -4, 'O': -2},
    ),
        "AA0595": ResidInfo(
        id="AA0595",
        name="coelenterazine",
        formula="C-1H-6O-2",
        monoisotopic_mass=-50.036779,
        average_mass=-50.06,
        dict_composition={'C': -1, 'H': -6, 'O': -2},
    ),
        "AA0596": ResidInfo(
        id="AA0596",
        name="L-isoglutamyl histamine",
        formula="C5H6N2",
        monoisotopic_mass=94.053098,
        average_mass=94.12,
        dict_composition={'C': 5, 'H': 6, 'N': 2},
    ),
        "AA0599": ResidInfo(
        id="AA0599",
        name="tetrakis-L-cysteinyl tetrairon octanitrosyl",
        formula="Fe4H-4N8O8",
        monoisotopic_mass=459.692359,
        average_mass=459.4,
        dict_composition={'Fe': 4, 'H': -4, 'N': 8, 'O': 8},
    ),
        "AA0600": ResidInfo(
        id="AA0600",
        name="L-alaninato bis-L-aspartato tris-L-glutamato L-histidino calcium tetramanganese pentoxide",
        formula="CaH-6Mn4O5",
        monoisotopic_mass=333.642394,
        average_mass=333.78,
        dict_composition={'Ca': 1, 'H': -6, 'Mn': 4, 'O': 5},
    ),
        "AA0601": ResidInfo(
        id="AA0601",
        name="(3R)-3-hydroxy-L-arginine",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0602": ResidInfo(
        id="AA0602",
        name="2-hydroxyproline",
        formula="O",
        monoisotopic_mass=15.994915,
        average_mass=16.0,
        dict_composition={'O': 1},
    ),
        "AA0603": ResidInfo(
        id="AA0603",
        name="bis-L-cysteinyl bisglutathion-S-yl diiron disulfide",
        formula="C20Fe2H30N6O12S4",
        monoisotopic_mass=785.950329,
        average_mass=786.42,
        dict_composition={'C': 20, 'Fe': 2, 'H': 30, 'N': 6, 'O': 12, 'S': 4},
    ),
        "AA0604": ResidInfo(
        id="AA0604",
        name="tris-L-cysteinyl L-glutamato tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.596734,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0605": ResidInfo(
        id="AA0605",
        name="tris-L-cysteinyl L-glutamin-O6-yl tetrairon tetrasulfide",
        formula="Fe4H-4S4",
        monoisotopic_mass=347.596734,
        average_mass=347.59,
        dict_composition={'Fe': 4, 'H': -4, 'S': 4},
    ),
        "AA0606": ResidInfo(
        id="AA0606",
        name="N4-(2,4-diacetamido-2,4,6-trideoxy-D-glucosyl)-L-asparagine",
        formula="C10H16N2O4",
        monoisotopic_mass=228.111007,
        average_mass=228.25,
        dict_composition={'C': 10, 'H': 16, 'N': 2, 'O': 4},
    ),
        "AA0607": ResidInfo(
        id="AA0607",
        name="O-(2,4-diacetamido-2,4,6-trideoxy-D-glucosyl)-L-serine",
        formula="C10H16N2O4",
        monoisotopic_mass=228.111007,
        average_mass=228.25,
        dict_composition={'C': 10, 'H': 16, 'N': 2, 'O': 4},
    ),
        "AA0608": ResidInfo(
        id="AA0608",
        name="O-(2-acetamido-4-glyceramido-2,4,6-trideoxy-D-glucosyl)-L-serine",
        formula="C11H18N2O6",
        monoisotopic_mass=274.116486,
        average_mass=274.27,
        dict_composition={'C': 11, 'H': 18, 'N': 2, 'O': 6},
    ),
        "AA0609": ResidInfo(
        id="AA0609",
        name="omega-N-(N-acetylamino)glucosyl-L-arginine",
        formula="C8H13NO5",
        monoisotopic_mass=203.079373,
        average_mass=203.19,
        dict_composition={'C': 8, 'H': 13, 'N': 1, 'O': 5},
    ),
        "AA0610": ResidInfo(
        id="AA0610",
        name="(2R,3R,2'R)-3-methyllanthionine",
        formula="H-2O-1",
        monoisotopic_mass=-18.010565,
        average_mass=-18.02,
        dict_composition={'H': -2, 'O': -1},
    ),
        "AA0611": ResidInfo(
        id="AA0611",
        name="S-(gamma-glutamyl-cysteinyl-glycyl)-cysteine",
        formula="C10H15N3O5S",
        monoisotopic_mass=289.073242,
        average_mass=289.31,
        dict_composition={'C': 10, 'H': 15, 'N': 3, 'O': 5, 'S': 1},
    ),
        "AA0612": ResidInfo(
        id="AA0612",
        name="5-glutamyl glutamic acid",
        formula="C5H7NO3",
        monoisotopic_mass=129.042593,
        average_mass=129.12,
        dict_composition={'C': 5, 'H': 7, 'N': 1, 'O': 3},
    ),
        "AA0613": ResidInfo(
        id="AA0613",
        name="5-glutamyl N2-ornithine",
        formula="C5H10N2O",
        monoisotopic_mass=114.079313,
        average_mass=114.15,
        dict_composition={'C': 5, 'H': 10, 'N': 2, 'O': 1},
    ),
        "AA0614": ResidInfo(
        id="AA0614",
        name="5-glutamyl coenzyme A thioester",
        formula="C21H34N7O15P3S",
        monoisotopic_mass=749.104644,
        average_mass=749.52,
        dict_composition={'C': 21, 'H': 34, 'N': 7, 'O': 15, 'P': 3, 'S': 1},
    ),
        "AA0615": ResidInfo(
        id="AA0615",
        name="N6-(3-phosphoglyceryl)-L-lysine",
        formula="C3H5O6P",
        monoisotopic_mass=167.982375,
        average_mass=168.04,
        dict_composition={'C': 3, 'H': 5, 'O': 6, 'P': 1},
    ),
        "AA0616": ResidInfo(
        id="AA0616",
        name="S-methyl-L-methionine",
        formula="CH3",
        monoisotopic_mass=15.022927,
        average_mass=15.03,
        dict_composition={'C': 1, 'H': 3},
    ),
        "AA0620": ResidInfo(
        id="AA0620",
        name="N,N-dimethylglycine",
        formula="C2H4",
        monoisotopic_mass=28.0313,
        average_mass=28.05,
        dict_composition={'C': 2, 'H': 4},
    ),
        "AA0621": ResidInfo(
        id="AA0621",
        name="2-(L-cystein-S-yl)-L-alanine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0622": ResidInfo(
        id="AA0622",
        name="2-(L-cystein-S-yl)-D-asparagine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0623": ResidInfo(
        id="AA0623",
        name="2-(L-cystein-S-yl)-L-serine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0624": ResidInfo(
        id="AA0624",
        name="2-(L-cystein-S-yl)-D-serine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0625": ResidInfo(
        id="AA0625",
        name="2-(L-cystein-S-yl)-L-threonine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
        "AA0626": ResidInfo(
        id="AA0626",
        name="2-(L-cystein-S-yl)-D-tyrosine",
        formula="H-2",
        monoisotopic_mass=-2.01565,
        average_mass=-2.02,
        dict_composition={'H': -2},
    ),
    }

    RESID_NAME_TO_ID: dict[str, str] = {
        mod.name: mod.id
        for mod in RESID_MODIFICATIONS.values()
    }
except Exception as e:
    warnings.warn(
        f"Exception in resid_data: {e}. Using empty dictionaries.",
        UserWarning,
        stacklevel=2
    )
    RESID_MODIFICATIONS: dict[str, ResidInfo] = {}
    RESID_NAME_TO_ID: dict[str, str] = {}
